/** done-coding-cli 注入配置 */
export declare const doneCodingCliConfig: InjectConfig;

/** 注入配置 */
declare interface InjectConfig {
    /** json文件相对路径 */
    sourceFilePath: string;
    /** 注入的key路径 */
    keyConfigMap: Record<string, InjectKeyConfig>;
    /** 注入信息文件路径 */
    injectFilePath: string;
}

/**
 * 注入配置
 * ---
 * 为 string 时 解析为 InjectKeyConfigFixed, 其中InjectKeyConfigFixed.value = string
 */
declare type InjectKeyConfig = InjectKeyConfigReg | (InjectKeyConfigFixed | string) | InjectKeyConfigRead;

/** 注入配置基础 */
declare interface InjectKeyConfigBase<T extends InjectTypeEnum> {
    /**
     * 提取类型
     */
    type: T;
}

/** 注入配置-固定值类型  */
declare interface InjectKeyConfigFixed extends InjectKeyConfigBase<InjectTypeEnum.FIXED> {
    /** 值 */
    value: string;
}

/** 注入配置-读取类型 */
declare interface InjectKeyConfigRead extends InjectKeyConfigBase<InjectTypeEnum.READ> {
    /** 源key */
    sourceKey?: string;
}

/** 注入配置-正则类型 */
declare interface InjectKeyConfigReg extends InjectKeyConfigBase<InjectTypeEnum.REG> {
    /**
     * 正则表达式字符串
     * ----
     * 不带flags
     */
    pattern: string;
    /** 正则匹配的 flags */
    flags?: string;
    /**
     * 替换值
     * ---
     * replace 第二个参数
     */
    replaceValue: string;
    /** 源key */
    sourceKey: string;
}

/** 配置类型枚举 */
declare enum InjectTypeEnum {
    /**
     * 正则表达式 类型
     */
    REG = "reg",
    /**
     * 固定值 类型
     */
    FIXED = "fixed",
    /**
     * 读取 类型
     */
    READ = "read"
}

export { }
