import { CliHandlerArgv } from '@done-coding/cli-utils';
import { CliInfo } from '@done-coding/cli-utils';
import { CommandModule } from 'yargs';
import type { InitConfigFileOptions } from '@done-coding/cli-utils';
import type { ReadConfigFileOptions } from '@done-coding/cli-utils';
import { SubCliInfo } from '@done-coding/cli-utils';

export declare const commandCliInfo: Omit<CliInfo, "usage">;

/** 作为子命令创建 */
export declare const crateAsSubcommand: () => CommandModule<{}, {}>;

export declare const generateCommandCliInfo: SubCliInfo;

/** 生成注入信息文件 */
export declare const generateFile: ({ rootDir, config, keyConfigMap: extractKeyConfigMap, }?: {
    rootDir?: string | undefined;
    config?: InjectConfig | undefined;
    keyConfigMap?: Record<string, InjectKeyConfig> | undefined;
}) => Promise<{} | undefined>;

/** 提取文件命令处理器 */
export declare const generateHandler: (argv: CliHandlerArgv<GenerateOptions>) => Promise<undefined>;

/** 生成选项 */
export declare type GenerateOptions = ReadConfigFileOptions;

export declare const handler: (command: SubcommandEnum, argv: CliHandlerArgv<any>) => Promise<void>;

export declare const initCommandCliInfo: SubCliInfo;

/** 初始化命令处理器 */
export declare const initHandler: (argv: CliHandlerArgv<InitOptions>) => Promise<void>;

/** 初始化选项 */
export declare type InitOptions = InitConfigFileOptions;

/** 注入配置 */
export declare interface InjectConfig {
    /** json文件相对路径 */
    sourceFilePath: string;
    /** 注入的key路径 */
    keyConfigMap: Record<string, InjectKeyConfig>;
    /** 注入信息文件路径 */
    injectFilePath: string;
}

/**
 * 注入配置
 * ---
 * 为 string 时 解析为 InjectKeyConfigFixed, 其中InjectKeyConfigFixed.value = string
 */
export declare type InjectKeyConfig = InjectKeyConfigReg | (InjectKeyConfigFixed | string) | InjectKeyConfigRead;

/** 注入配置基础 */
export declare interface InjectKeyConfigBase<T extends InjectTypeEnum> {
    /**
     * 提取类型
     */
    type: T;
}

/** 注入配置-固定值类型  */
export declare interface InjectKeyConfigFixed extends InjectKeyConfigBase<InjectTypeEnum.FIXED> {
    /** 值 */
    value: string;
}

/** 注入配置-读取类型 */
export declare interface InjectKeyConfigRead extends InjectKeyConfigBase<InjectTypeEnum.READ> {
    /** 源key */
    sourceKey?: string;
}

/** 注入配置-正则类型 */
export declare interface InjectKeyConfigReg extends InjectKeyConfigBase<InjectTypeEnum.REG> {
    /**
     * 正则表达式字符串
     * ----
     * 不带flags
     */
    pattern: string;
    /** 正则匹配的 flags */
    flags?: string;
    /**
     * 替换值
     * ---
     * replace 第二个参数
     */
    replaceValue: string;
    /** 源key */
    sourceKey: string;
}

/** 配置类型枚举 */
export declare enum InjectTypeEnum {
    /**
     * 正则表达式 类型
     */
    REG = "reg",
    /**
     * 固定值 类型
     */
    FIXED = "fixed",
    /**
     * 读取 类型
     */
    READ = "read"
}

/** key配置解析-获取最终值 */
export declare const keyConfigResolve: ({ sourceJson, targetKey, keyConfig: keyConfigInit, }: {
    sourceJson: Record<string, any>;
    targetKey: string;
    keyConfig: InjectKeyConfig;
}) => any;

/** @deprecated */
export declare interface Options {
    /** json文件相对路径 */
    sourceJsonFilePath: string;
    /** 注入的key路径 */
    injectKeyPath: string[];
    /** 注入信息文件路径 */
    injectInfoFilePath: string;
}

/** 子命令枚举 */
export declare enum SubcommandEnum {
    /** 初始化提取配置文件 */
    INIT = "init",
    /** 生成文件 */
    GENERATE = "generate"
}

export { }
